@@ -1,6 +1,6 @@
 """Chord transcription for both MIDI and audio domain.
 
-Re-implementation from the repository
+Re-implementation of the repository
 `Tsung-Ping/Harmony-Transformer <https://github.com/Tsung-Ping/Harmony-Transformer>`_.
 
 Feature Storage Format
