@@ -1,5 +1,6 @@
 import click
 
+from omnizart.cli import silence_tensorflow
 from omnizart.cli.common_options import add_common_options, COMMON_TRAIN_MODEL_OPTIONS
 from omnizart.setting_loaders import DrumSettings
 from omnizart.utils import LazyLoader
@@ -37,4 +38,5 @@ def train_model(
     if early_stop is not None:
         settings.training.early_stop = early_stop
 
+    silence_tensorflow()
     drum.app.train(feature_path, model_name=model_name, input_model_path=input_model, drum_settings=settings)
